OC.L10N.register(
    "tasks",
    {
    "Today" : "Hari ini",
    "Week" : "Minggu",
    "Can edit" : "Can edit",
    "Edit" : "Sunting",
    "Export" : "Eksport",
    "Delete" : "Padam",
    "Name" : "Nama",
    "Deleted" : "Dipadam",
    "Restore" : "Pulihkan",
    "Cancel" : "Batal",
    "Close" : "Tutup",
    "Notes" : "Nota",
    "Repeat" : "Ulang"
},
"nplurals=1; plural=0;");
