OC.L10N.register(
    "tasks",
    {
    "Important" : "اہم",
    "Today" : "آج",
    "Week" : "ہفتہ",
    "Tasks" : "کام",
    "Can edit" : "Can edit",
    "Edit" : "تدوین کریں",
    "Delete" : "حذف کریں",
    "Unshare" : "شئیرنگ ختم کریں",
    "Name" : "اسم",
    "Deleted" : "حذف شدہ ",
    "Restore" : "بحال",
    "Cancel" : "منسوخ کریں",
    "Close" : "بند ",
    "Notes" : "Notes",
    "Repeat" : "دہرایں"
},
"nplurals=2; plural=(n != 1);");
