.material-design-icon[data-v-033a4c57]{display:flex;align-self:center;justify-self:center;align-items:center;justify-content:center}li.action.active[data-v-033a4c57]{background-color:var(--color-background-hover);border-radius:6px;padding:0}.action--disabled[data-v-033a4c57]{pointer-events:none;opacity:.5}.action--disabled[data-v-033a4c57]:hover,.action--disabled[data-v-033a4c57]:focus{cursor:default;opacity:.5}.action--disabled[data-v-033a4c57] *{opacity:1!important}.action-button[data-v-033a4c57]{display:flex;align-items:flex-start;width:100%;height:auto;margin:0;padding:0 14px 0 0;box-sizing:border-box;cursor:pointer;white-space:nowrap;color:var(--color-main-text);border:0;border-radius:0;background-color:transparent;box-shadow:none;font-weight:400;font-size:var(--default-font-size);line-height:44px}.action-button>span[data-v-033a4c57]{cursor:pointer;white-space:nowrap}.action-button__icon[data-v-033a4c57]{width:44px;height:44px;opacity:1;background-position:14px center;background-size:16px;background-repeat:no-repeat}.action-button[data-v-033a4c57] .material-design-icon{width:44px;height:44px;opacity:1}.action-button[data-v-033a4c57] .material-design-icon .material-design-icon__svg{vertical-align:middle}.action-button__longtext-wrapper[data-v-033a4c57],.action-button__longtext[data-v-033a4c57]{max-width:220px;line-height:1.6em;padding:10.8px 0;cursor:pointer;text-align:left;overflow:hidden;text-overflow:ellipsis}.action-button__longtext[data-v-033a4c57]{cursor:pointer;white-space:pre-wrap!important}.action-button__name[data-v-033a4c57]{font-weight:700;text-overflow:ellipsis;overflow:hidden;white-space:nowrap;max-width:100%;display:inline-block}.action-button__menu-icon[data-v-033a4c57],.action-button__pressed-icon[data-v-033a4c57]{margin-left:auto;margin-right:-14px}
