.task-icon[data-v-b78bc47d],.material-design-icon[data-v-ac2fc36c]{display:flex;align-self:center;justify-self:center;align-items:center;justify-content:center}.dashboard-widget[data-v-ac2fc36c] .empty-content{text-align:center;padding-top:5vh}.dashboard-widget[data-v-ac2fc36c] .empty-content.half-screen{padding-top:0;margin-bottom:1vh}.more[data-v-ac2fc36c]{display:block;text-align:center;color:var(--color-text-maxcontrast);line-height:60px;cursor:pointer}.more[data-v-ac2fc36c]:hover,.more[data-v-ac2fc36c]:focus{background-color:var(--color-background-hover);border-radius:var(--border-radius-large);color:var(--color-main-text)}.item-list__entry[data-v-ac2fc36c]{display:flex;align-items:flex-start;padding:8px}.item-list__entry .item-avatar[data-v-ac2fc36c]{position:relative;margin-top:auto;margin-bottom:auto;background-color:var(--color-background-dark)!important}.item-list__entry .item__details[data-v-ac2fc36c]{padding-left:8px;max-height:44px;flex-grow:1;overflow:hidden;display:flex;flex-direction:column}.item-list__entry .item__details h3[data-v-ac2fc36c],.item-list__entry .item__details .message[data-v-ac2fc36c]{white-space:nowrap;background-color:var(--color-background-dark)}.item-list__entry .item__details h3[data-v-ac2fc36c]{font-size:100%;margin:0}.item-list__entry .item__details .message[data-v-ac2fc36c]{width:80%;height:15px;margin-top:5px}.material-design-icon[data-v-c1cd11d9]{display:flex;align-self:center;justify-self:center;align-items:center;justify-content:center}.item-list__entry[data-v-c1cd11d9]{display:flex;align-items:flex-start;position:relative;padding:8px}.item-list__entry[data-v-c1cd11d9]:hover,.item-list__entry[data-v-c1cd11d9]:focus{background-color:var(--color-background-hover);border-radius:var(--border-radius-large)}.item-list__entry .item-avatar[data-v-c1cd11d9]{position:relative;margin-top:auto;margin-bottom:auto}.item-list__entry .item__details[data-v-c1cd11d9]{padding-left:8px;max-height:44px;flex-grow:1;overflow:hidden;display:flex;flex-direction:column;justify-content:center;min-height:44px}.item-list__entry .item__details h3[data-v-c1cd11d9],.item-list__entry .item__details .message[data-v-c1cd11d9]{white-space:nowrap;overflow:hidden;text-overflow:ellipsis}.item-list__entry .item__details .message span[data-v-c1cd11d9]{width:10px;display:inline-block;margin-bottom:-3px}.item-list__entry .item__details h3[data-v-c1cd11d9]{font-size:100%;margin:0}.item-list__entry .item__details .message[data-v-c1cd11d9]{width:100%;color:var(--color-text-maxcontrast)}.item-list__entry .item-icon[data-v-c1cd11d9]{position:relative;width:14px;height:14px;margin:27px -3px 0 -7px}.item-list__entry button.primary[data-v-c1cd11d9]{padding:21px;margin:0}#tasks_panel .calendar-dot{height:1rem;width:1rem;margin-top:.2rem;border-radius:50%;min-width:1rem;min-height:1rem}.center-button{display:flex;justify-content:center;margin-top:10px}
