/* extracted by css-entry-points-plugin */
@import './dashboard-DSqnlcV-.chunk.css';
@import './store-BZeWfrS_.chunk.css';
@import './TaskCreateDialog-Cvf7jBdo.chunk.css';
@import './Plus-CnHTUEFt.chunk.css';