OC.L10N.register(
    "tasks",
    {
    "Important" : "مۇھىم",
    "Today" : "بۈگۈن",
    "Week" : "ھەپتە",
    "All" : "ھەممىسى",
    "Tasks" : "ۋەزىپەلەر",
    "Can edit" : "Can edit",
    "Edit" : "تەھرىر",
    "Export" : "چىقار",
    "Delete" : "ئۆچۈر",
    "Unshare" : "ھەمبەھىرلىمە",
    "Name" : "ئاتى",
    "Deleted" : "ئۆچۈرۈلدى",
    "Delete permanently" : "مەڭگۈلۈك ئۆچۈر",
    "Cancel" : "ۋاز كەچ",
    "Close" : "ياپ",
    "Notes" : "ئىزاھاتلار",
    "Repeat" : "قايتىلا"
},
"nplurals=2; plural=(n != 1);");
