OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Próximas tareas",
    "Important" : "Importante",
    "Today" : "Hoy",
    "Week" : "Semana",
    "All" : "Todos",
    "Current" : "Actual",
    "Completed" : "Completado",
    "Tasks" : "Tareas",
    "The Tasks app for Nextcloud" : "Una aplicación de Tareas para Nextcloud",
    "Visibility of Smart Collections" : "Visibilidad de Colecciones Inteligentes",
    "Hidden" : "Oculto",
    "Visible" : "Visible",
    "Automatic" : "Automático",
    "Share with users or groups" : "Compartir con otros usuarios o grupos",
    "No users or groups" : "Sin usuarios ni grupos",
    "Can edit" : "Puede editar",
    "Unshare with {displayName}" : "Dejar de compartir con {displayName}",
    "Edit" : "Editar",
    "Export" : "Exportar",
    "Delete" : "Borrar",
    "Unshare" : "Dejar de compartir",
    "Calendar link copied to clipboard." : "Enlace del calendario copiado al portapapeles.",
    "Calendar link could not be copied to clipboard." : "No se pudo copiar el enlace del calendario al portapapeles.",
    "An empty name is not allowed." : "No se permite un nombre vacío.",
    "An error occurred, unable to delete the calendar." : "Ocurrió un error, no se pudo eliminar el calendario.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Eliminando el calendario en {countdown} segundo","Eliminando el calendario en {countdown} segundos","Eliminando el calendario en {countdown} segundos"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Dejando de compartir el calendario en {countdown} segundo","Dejando de compartir el calendario en {countdown} segundos","Dejando de compartir el calendario en {countdown} segundos"],
    "Trash bin" : "Papelera",
    "Name" : "Nombre",
    "Deleted" : "Eliminado",
    "Restore" : "Restaurar",
    "Delete permanently" : "Borrar permanentemente",
    "Empty trash bin" : "Vaciar la papelera de reciclaje",
    "Untitled task" : "Tarea sin título",
    "Untitled event" : "Evento sin título",
    "Untitled item" : "Elemento sin título",
    "Unknown calendar" : "Calendario desconocido",
    "Could not load deleted calendars and objects" : "No se pudieron cargar los calendarios y objetos eliminados",
    "Could not restore calendar or event" : "No se pudo restaurar el calendario o evento",
    "Do you really want to empty the trash bin?" : "¿Realmente desea vaciar la papelera?",
    "Cancel" : "Cancelar",
    "Close" : "Cerrar",
    "Select tags to filter by" : "Selecciona las etiquetas del filtro",
    "Change sort order" : "Cambiar el criterio para ordenar",
    "Start date" : "Fecha de inicio",
    "Due date" : "Fecha de vencimiento",
    "Last modified" : "Última modificación",
    "Priority" : "Prioridad",
    "Alphabetically" : "Alfabéticamente",
    "Manually" : "Manualmente",
    "Delete task" : "Eliminar tarea",
    "[Yesterday]" : "[Ayer]",
    "[Today]" : "[Hoy]",
    "[Tomorrow]" : "[Mañana]",
    "Task is completed" : "La tarea ha sido completada",
    "Create a new task" : "Crear una tarea nueva",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tarea Completada","%n Tareas Completadas","%n Tareas Completadas"],
    "Tomorrow" : "Mañana",
    "Add List…" : "Crear Lista...",
    "All day" : "Todo el día",
    "Details" : "Detalles",
    "Select tags" : "Selecciona las etiquetas",
    "Notes" : "Notas",
    "Reminders" : "Recordatorios",
    "Repeat" : "Repetir",
    "When shared show full event" : "Al compartir, mostrar el evento completo",
    "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
    "When shared hide this event" : "Al compartir, ocultar este evento ",
    "Canceled" : "Cancelada",
    "Task not found!" : "¡Tarea no encontrada!",
    "Set start date" : "Establecer fecha de inicio",
    "Set due date" : "Establecer fecha de vencimiento",
    "No upcoming tasks" : "No hay tareas próximas",
    "upcoming tasks" : "tareas próximas",
    "Mark as done" : "Marcar como hecho",
    "No due date assigned" : "Fecha de vencimiento sin especificar",
    "Synchronizing to the server." : "Sincronizando con el servidor.",
    "An error occurred" : "Ha ocurrido un error"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
