OC.L10N.register(
    "tasks",
    {
    "Important" : "Svarīgi",
    "Today" : "Šodien",
    "Week" : "Nedēļa",
    "All" : "Visi",
    "Current" : "Pašreizējais",
    "Completed" : "Pabeigts",
    "Tasks" : "Uzdevumi",
    "Visibility of Smart Collections" : "Viedo kolekciju redzamība",
    "Hidden" : "Paslēpts",
    "Visible" : "Redzams",
    "Automatic" : "Automātisks",
    "Share with users or groups" : "Koplietot ar lietotājiem vai grupām",
    "No users or groups" : "Nav lietotāji vai grupas",
    "Can edit" : "Var labot",
    "Unshare with {displayName}" : "Atcelt kopīgošanu ar {displayName}",
    "Unable to delete the share." : "Nevar izdzēst kopīgošanu.",
    "Unable to change permissions." : "Nevar mainīt atļaujas.",
    "Edit" : "Labot",
    "Copied" : "Nokopēts",
    "Export" : "Eksportēt",
    "Delete" : "Dzēst",
    "Unshare" : "Pārtraukt dalīšanos",
    "Calendar link copied to clipboard." : "Kalendāra saite nokopēta starpliktuvē.",
    "Calendar link could not be copied to clipboard." : "Kalendāra saiti nevar nokopēt starpliktuvē.",
    "An empty name is not allowed." : "Nosaukums ir obligāts.",
    "An error occurred, unable to delete the calendar." : "Radās kļūda, neizdevās izdzēst kalendāru.",
    "Trash bin" : "Miskaste",
    "Name" : "Vārds",
    "Deleted" : "Dzēstie",
    "Restore" : "Atjaunot",
    "Delete permanently" : "Dzēst pavisam",
    "Empty trash bin" : "Izdzēst miskastes saturu",
    "Untitled task" : "Uzdevums bez nosaukuma",
    "Untitled event" : "Nenosaukts notikums",
    "Untitled item" : "Nenosaukts vienums",
    "Unknown calendar" : "Nezināms kalendārs",
    "Could not load deleted calendars and objects" : "Nevarēja ielādēt dzēstos kalendārus un objektus",
    "Could not restore calendar or event" : "Nevarēja atjaunot kalendāru vai notikumu.",
    "Do you really want to empty the trash bin?" : "Vai esat pārliecināts, ka vēlaties neatgriezeniski dzēst miskastes saturu?",
    "Cancel" : "Atcelt",
    "Close" : "Aizvērt",
    "No errors" : "Nav kļūdu",
    "Open your browser console for more details" : "Jāatver savas pārlūkprogrammas konsole, lai uzzinātu vairāk",
    "Select tags to filter by" : "Izvēlieties birkas, pēc kurām filtrēt",
    "Change sort order" : "Mainīt kārtošanas secību",
    "Start date" : "Sākuma datums",
    "Due date" : "Izpildes datums",
    "Last modified" : "Pēdējoreiz modificēts",
    "Priority" : "Prioritāte",
    "Alphabetically" : "Alfabētiskā secībā",
    "Manually" : "Manuāli",
    "Hide subtasks" : "Slēpt apakšuzdevumus",
    "Hide closed subtasks" : "Slēpt slēgtos apakšuzdevumus",
    "Task is completed" : "Uzdevums pabeigts",
    "_%n Completed Task_::_%n Completed Tasks_" : ["neviena pabeigta uzdevuma","%n paeigts uzdevums","%n pabeigti uzvedumi"],
    "Tomorrow" : "Rīt",
    "All day" : "Visas dienas",
    "Details" : "Detaļas",
    "Select tags" : "Izvēlies birkas",
    "Notes" : "Piezīmes",
    "Reminders" : "Atgādinājumi",
    "Repeat" : "Atkārtot",
    "When shared show full event" : "Ja koplietots, tad rādīt pilnu notikumu",
    "When shared show only busy" : "Ja koplietots, tad rādīt tikai aizņemts",
    "When shared hide this event" : "Ja koplietots, tad paslēpt notikumu",
    "Canceled" : "Atcelts",
    "Task not found!" : "Uzdevums nav atrasts!",
    "Set start date" : "Uzstādīt sākuma datumu",
    "Set due date" : "Uzstādīt izpildes termiņu",
    "Task successfully moved to new calendar." : "Uzdevums veiksmīgi pārvietots uz jaunu kalendāru.",
    "An error occurred" : "Gadījās kļūda"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
